@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::PortabilityTests;
-our $VERSION = '1.100690';
+our $VERSION = '1.100700';
 # ABSTRACT: release tests for portability
 use Moose;
 use Test::Portability::Files ();
@@ -24,7 +24,7 @@ Dist::Zilla::Plugin::PortabilityTests - release tests for portability
 
 =head1 VERSION
 
-version 1.100690
+version 1.100700
 
 =head1 SYNOPSIS
 
@@ -39,10 +39,32 @@ following files
 
   xt/release/portability.t - a standard Test::Portability::Files test
 
+=for test_synopsis 1;
+__END__
+
 =head1 INSTALLATION
 
 See perlmodinstall for information and options on installing Perl modules.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-PortabilityTests>.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Dist-Zilla-Plugin-PortabilityTests/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Dist-Zilla-Plugin-PortabilityTests/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
@@ -64,6 +86,6 @@ ___[ xt/release/portability.t ]___
 use Test::More;
 
 eval "use Test::Portability::Files";
-plan skip_all => "Test::Kwalitee required for testing kwalitee"
+plan skip_all => "Test::Portability::Files required for testing portability"
   if $@;
 run_tests();
